#include <inttypes.h>

int32_t
do_nothing_really_well_abcdef(void) {
    return 0;
}
